@@ -45,6 +45,9 @@ class BigWigDataset(Dataset):
         factor_fasta_folder,
         bigwig_folder,
         enformer_loci_path,
+        human_fasta_file,
+        mouse_fasta_file,
+        mouse_factor_fasta_folder = None,
         annot_file = None,
         filter_chromosome_ids = None,
         exclude_targets = None,
@@ -60,6 +63,7 @@ class BigWigDataset(Dataset):
         only_ref = ['mm10', 'hg38'],
         downsample_factor = 128,
         target_length = 896,
+        bigwig_reduction_type = 'sum',
         **kwargs
     ):
         super().__init__()
@@ -91,6 +95,8 @@ class BigWigDataset(Dataset):
         loci = loci.filter(pl_isin('column_1', get_chr_names(dataset_chr_ids)))
 
         self.factor_ds = FactorProteinDataset(factor_fasta_folder)
+        self.mouse_factor_ds = self.factor_ds if not exists(mouse_factor_fasta_folder) else FactorProteinDataset(mouse_factor_fasta_folder)
+
         annot_df = chip_atlas_add_experiment_target_cell(annot_df)
         annot_df = filter_df_by_tfactor_fastas(annot_df, factor_fasta_folder)
 
@@ -122,7 +128,9 @@ class BigWigDataset(Dataset):
 
         assert len(annot_df) > 0, 'dataset is empty by filter criteria'
 
-        self.fasta = FastaInterval(**kwargs)
+        self.human_fasta = FastaInterval(fasta_file = human_fasta_file, **kwargs)
+        self.mouse_fasta = FastaInterval(fasta_file = mouse_fasta_file, **kwargs)
+
         self.df = loci
         self.annot = annot_df
         self.ntargets = self.annot.shape[0]
@@ -134,6 +142,8 @@ class BigWigDataset(Dataset):
         self.downsample_factor = downsample_factor
         self.target_length = target_length
 
+        self.bigwig_reduction_type = bigwig_reduction_type
+
     def __len__(self):
         return len(self.df) * self.ntargets
 
@@ -142,17 +152,31 @@ class BigWigDataset(Dataset):
 
         chr_name, begin, end, _ = self.df.row(ind % self.df.shape[0])
 
-        target = self.annot.select('target').to_series(0)
+        targets = self.annot.select('target').to_series(0)
         cell_types = self.annot.select('cell_type').to_series(0)
+        refs = self.annot.select('column_2').to_series(0)
 
         ix_target = ind // self.df.shape[0]
     
         #experiment, target, cell_type = parse_exp_target_cell(experiment_target_cell_type)
 
-        seq = self.fasta(chr_name, begin, end)
-
-        aa_seq = self.factor_ds[target[ix_target]]
+        target = targets[ix_target]
         context_str = cell_types[ix_target]
+        ref = refs[ix_target]
+
+        # figure out ref and fetch appropriate sequence
+
+        if ref == 'hg38':
+            fasta = self.human_fasta
+            factor_ds = self.factor_ds
+        elif ref == 'mm10':
+            fasta = self.mouse_fasta
+            factor_ds = self.mouse_factor_ds
+        else:
+            raise ValueError(f'unknown ref {ref}')
+
+        aa_seq = factor_ds[target]
+        seq = fasta(chr_name, begin, end)
 
         # calculate bigwig
         # properly downsample and then crop
@@ -161,7 +185,13 @@ class BigWigDataset(Dataset):
         output = np.array(exp_bw.values(chr_name, begin, end))
 
         output = output.reshape((-1, self.downsample_factor))
-        om = np.nanmean(output, axis = 1)
+
+        if self.bigwig_reduction_type == 'mean':
+            om = np.nanmean(output, axis = 1)
+        elif self.bigwig_reduction_type == 'sum':
+            om = np.nansum(output, axis = 1)
+        else:
+            raise ValueError(f'unknown reduction type {self.bigwig_reduction_type}')
 
         output_length = output.shape[0]
 
