@@ -1,30 +1,12 @@
 import torch
 from torch import nn
-from torch.optim import AdamW
+from tf_bind_transformer.optimizer import get_optimizer
 from tf_bind_transformer.data import read_bed, collate_dl_outputs, get_dataloader, remap_df_add_experiment_target_cell
 from tf_bind_transformer.data import RemapAllPeakDataset, NegativePeakDataset, ScopedNegativePeakDataset
 
 def exists(val):
     return val is not None
 
-def separate_weight_decayable_params(params):
-    no_wd_params = set([param for param in params if param.ndim < 2])
-    wd_params = set(params) - no_wd_params
-    return wd_params, no_wd_params
-
-def get_optimizer(params, lr = 3e-4, wd = 1e-1, filter_by_requires_grad = False):
-    if filter_by_requires_grad:
-        params = list(filter(lambda t: t.requires_grad, params))
-
-    params = set(params)
-    wd_params, no_wd_params = separate_weight_decayable_params(params)
-
-    param_groups = [
-        {'params': list(wd_params)},
-        {'params': list(no_wd_params), 'weight_decay': 0},
-    ]
-
-    return AdamW(param_groups, lr = lr, weight_decay = wd)
 
 # helpers for logging and accumulating values across gradient steps
 
@@ -247,9 +229,6 @@ class Trainer(nn.Module):
         if (curr_step % self.validate_every) == 0:
             self.model.eval()
 
-            total_valid_loss = 0
-            total_valid_accuracies = 0
-
             for _ in range(self.grad_accum_every):
                 seq, tf_aa, contextual_texts, peaks_nr, read_value, binary_target = collate_dl_outputs(next(self.valid_dl), next(self.valid_neg_dl))
                 seq, binary_target = seq.cuda(), binary_target.cuda()
@@ -263,9 +242,6 @@ class Trainer(nn.Module):
                 valid_loss = self.model.loss_fn(valid_logits, binary_target.float())
                 valid_accuracy = ((valid_logits.sigmoid() > 0.5).int() == binary_target).sum() / (binary_target.numel())
 
-                total_valid_loss += valid_loss.item()
-                total_valid_accuracies += valid_accuracy.item()
-
                 log = accum_log(log, {
                     'valid_loss': valid_loss.item() / grad_accum_every,
                     'valid_accuracy': valid_accuracy.item() / grad_accum_every
