@@ -29,7 +29,8 @@ class BigWigTrainer(nn.Module):
         bigwig_folder_path,
         loci_path,
         annot_file_path,
-        fasta_file,
+        human_fasta_file,
+        mouse_fasta_file,
         train_chromosome_ids,
         valid_chromosome_ids,
         batch_size,
@@ -54,7 +55,8 @@ class BigWigTrainer(nn.Module):
         include_biotypes_metadata_in_context = False,
         biotypes_metadata_path = None,
         include_biotypes_metadata_columns = ['germ_layer', 'cellline_cat'],
-        biotypes_metadata_delimiter = ' | '
+        biotypes_metadata_delimiter = ' | ',
+        bigwig_reduction_type = 'sum'
     ):
         super().__init__()
         self.model = model
@@ -65,7 +67,8 @@ class BigWigTrainer(nn.Module):
             bigwig_folder = bigwig_folder_path,
             enformer_loci_path = loci_path,
             annot_file = annot_file_path,
-            fasta_file = fasta_file,
+            human_fasta_file = human_fasta_file,
+            mouse_fasta_file = mouse_fasta_file,
             exclude_targets = held_out_targets,
             exclude_cell_types = held_out_cell_types,
             only_ref = only_ref,
@@ -73,6 +76,7 @@ class BigWigTrainer(nn.Module):
             downsample_factor = downsample_factor,
             shift_augs = shift_aug_range,
             rc_aug = rc_aug,
+            bigwig_reduction_type = bigwig_reduction_type
         )
 
         self.valid_ds = BigWigDataset(
@@ -81,6 +85,8 @@ class BigWigTrainer(nn.Module):
             bigwig_folder = default(valid_bigwig_folder_path, bigwig_folder_path),
             enformer_loci_path = default(valid_loci_path, loci_path),
             annot_file = default(valid_annot_file_path, annot_file_path),
+            human_fasta_file = human_fasta_file,
+            mouse_fasta_file = mouse_fasta_file,
             fasta_file = fasta_file,
             include_targets = held_out_targets,
             include_cell_types = held_out_cell_types,
@@ -89,6 +95,7 @@ class BigWigTrainer(nn.Module):
             downsample_factor = downsample_factor,
             shift_augs = shift_aug_range,
             rc_aug = rc_aug,
+            bigwig_reduction_type = bigwig_reduction_type
         )
 
         self.train_dl = get_bigwig_dataloader(self.ds, cycle_iter = True, shuffle = shuffle, batch_size = batch_size)
